"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const context_1 = require("./context");
const getConfig_1 = require("./config/getConfig");
const getWorkspace_1 = require("./workspace/getWorkspace");
const args_1 = require("./args");
const reportSummary_1 = require("./logger/reportSummary");
const taskRunner_1 = require("./task/taskRunner");
const logger_1 = require("./logger");
const generateTopologicalGraph_1 = require("./workspace/generateTopologicalGraph");
const abortSignal_1 = require("./task/abortSignal");
const npmTask_1 = require("./task/npmTask");
console.log(`🧱 Lage task runner 🧱`);
console.log(``);
// Parse CLI args
const parsedArgs = args_1.parseArgs();
args_1.validateInput(parsedArgs);
// Create context
const cwd = process.cwd();
const config = getConfig_1.getConfig(cwd);
const context = context_1.createContext(config);
const workspace = getWorkspace_1.getWorkspace(cwd, config);
// Initialize logger
if (config.verbose) {
    logger_1.logLevel("verbose");
}
// generate topological graph
const graph = generateTopologicalGraph_1.generateTopologicGraph(workspace);
(async () => {
    const { profiler } = context;
    context.measures.start = process.hrtime();
    // die faster if an abort signal is seen
    abortSignal_1.signal.addEventListener("abort", () => {
        npmTask_1.killAllActiveProcesses();
        displayReportAndExit();
    });
    try {
        await taskRunner_1.runTasks({ graph, workspace, context, config });
    }
    catch (e) {
        logger_1.logger.error("runTasks", e);
    }
    if (config.profile) {
        const profileFile = profiler.output();
        logger_1.logger.info("runTasks", `Profile saved to ${profileFile}`);
    }
    displayReportAndExit();
})();
function displayReportAndExit() {
    context.measures.duration = process.hrtime(context.measures.start);
    reportSummary_1.reportSummary(context);
    if (context.measures.failedTask) {
        process.exit(1);
    }
}
